==> ruta-2.8.1-source-release.zip: ruta-2.8.1/ruta-core/src/test/java/org/apache/uima/ruta/engine/RutaCutterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.engine;

import java.util.Collection;

import org.apache.uima.analysis_engine.AnalysisEngine;
import org.apache.uima.fit.factory.AnalysisEngineFactory;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;
import org.apache.uima.ruta.type.TruePositive;
import org.junit.Assert;
import org.junit.Test;


public class RutaCutterTest {

  @Test
  public void test() throws Exception {
    
    JCas jcas = JCasFactory.createJCas();
    AnalysisEngine cutter = AnalysisEngineFactory.createEngine(RutaCutter.class, RutaCutter.PARAM_KEEP, TruePositive.class.getName());
    jcas.setDocumentText("Some text.");
    Ruta.apply(jcas.getCas(), "SW{-> TruePositive};");
    cutter.process(jcas);

    Collection<TruePositive> select = JCasUtil.select(jcas, TruePositive.class);
    Assert.assertEquals(1, select.size());
    TruePositive truePositive = select.iterator().next();
    Assert.assertEquals(5, truePositive.getBegin());
    
    JCas cuttedView = jcas.getView("cutted");
    Assert.assertEquals("text", cuttedView.getDocumentText());
    select = JCasUtil.select(cuttedView, TruePositive.class);
    Assert.assertEquals(1, select.size());
    truePositive = select.iterator().next();
    Assert.assertEquals(0, truePositive.getBegin());
    
    jcas.release();
    cutter.destroy();
  }

  
}

==> ruta-3.5.0-source-release.zip: ruta-3.5.0/ruta-core/src/test/java/org/apache/uima/ruta/engine/RutaCutterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.engine;

import static org.assertj.core.api.Assertions.assertThat;

import java.util.Collection;

import org.apache.uima.analysis_engine.AnalysisEngine;
import org.apache.uima.fit.factory.AnalysisEngineFactory;
import org.apache.uima.fit.factory.JCasFactory;
import org.apache.uima.fit.util.JCasUtil;
import org.apache.uima.jcas.JCas;
import org.apache.uima.ruta.type.TruePositive;
import org.junit.jupiter.api.Test;

public class RutaCutterTest {

  @Test
  public void test() throws Exception {

    JCas jcas = JCasFactory.createJCas();
    AnalysisEngine cutter = AnalysisEngineFactory.createEngine(RutaCutter.class,
            RutaCutter.PARAM_KEEP, TruePositive.class.getName());
    jcas.setDocumentText("Some text.");
    Ruta.apply(jcas.getCas(), "SW{-> TruePositive};");
    cutter.process(jcas);

    Collection<TruePositive> select = JCasUtil.select(jcas, TruePositive.class);
    assertThat(select).hasSize(1);
    TruePositive truePositive = select.iterator().next();
    assertThat(truePositive.getBegin()).isEqualTo(5);

    JCas cuttedView = jcas.getView("cutted");
    assertThat(cuttedView.getDocumentText()).isEqualTo("text");
    select = JCasUtil.select(cuttedView, TruePositive.class);
    assertThat(select).hasSize(1);
    truePositive = select.iterator().next();
    assertThat(truePositive.getBegin()).isEqualTo(0);

    jcas.release();
    cutter.destroy();
  }

}
